==> spl-0.4.9.tar.gz: spl-0.4.9/module/splat/splat.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
 .arch = MODULE_ARCH_INIT,
};

static const struct modversion_info ____versions[]
__used
__attribute__((section("__versions"))) = {
	{ 0x4272164, "module_layout" },
	{ 0xbda68fe3, "vn_fsync" },
	{ 0x1b7a8e86, "kobject_put" },
	{ 0xcda85fb, "cdev_del" },
	{ 0x70e0e73a, "per_cpu__current_task" },
	{ 0x5a34a45c, "__kmalloc" },
	{ 0x70762af4, "cdev_init" },
	{ 0xf9a482f9, "msleep" },
	{ 0xe23d7acb, "up_read" },
	{ 0x1c1af916, "set_normalized_timespec" },
	{ 0x3feff267, "call_usermodehelper_exec" },
	{ 0xd6ee688f, "vmalloc" },
	{ 0x25ec1b28, "strlen" },
	{ 0xa999ab7a, "crhold" },
	{ 0xf41f6d7, "vn_close" },
	{ 0xd8e484f0, "register_chrdev_region" },
	{ 0xfa2e111f, "slab_buffer_size" },
	{ 0x448411f4, "crgetruid" },
	{ 0xc8b57c27, "autoremove_wake_function" },
	{ 0x6c895286, "vn_getattr" },
	{ 0x950ffff2, "cpu_online_mask" },
	{ 0x79aa04a2, "get_random_bytes" },
	{ 0x67053080, "current_kernel_time" },
	{ 0xb5afb493, "kmem_free_debug" },
	{ 0xd691cba2, "malloc_sizes" },
	{ 0x7440fcaf, "rootdir" },
	{ 0xb4279ab7, "downgrade_write" },
	{ 0xe452ee8c, "kobj_close_file" },
	{ 0x973873ab, "_spin_lock" },
	{ 0xc0a3d105, "find_next_bit" },
	{ 0x49e1192d, "kobj_get_filesize" },
	{ 0x6248c005, "crgetngroups" },
	{ 0x105e2727, "__tracepoint_kmalloc" },
	{ 0xc37c9813, "device_destroy" },
	{ 0x8ce35dc9, "kobject_set_name" },
	{ 0xf7756b61, "vn_rename" },
	{ 0x2358cc7b, "filp_close" },
	{ 0x56b27c, "crgetgroups" },
	{ 0x43f769bb, "__taskq_dispatch" },
	{ 0x8045091, "mutex_unlock" },
	{ 0x39f37598, "vn_rdwr" },
	{ 0x7485e15e, "unregister_chrdev_region" },
	{ 0x999e8297, "vfree" },
	{ 0x712aa29b, "_spin_lock_irqsave" },
	{ 0x12f16266, "crgetsuid" },
	{ 0x3c2c5af5, "sprintf" },
	{ 0xe330ba71, "vmem_alloc_debug" },
	{ 0x1190455e, "spl_kmem_cache_free" },
	{ 0x53c639a, "ddi_strtoul" },
	{ 0x7d11c268, "jiffies" },
	{ 0x343a1a8, "__list_add" },
	{ 0x8233de06, "mutex_trylock" },
	{ 0xb4b0ee4e, "down_read" },
	{ 0x24e4bb01, "down_write_trylock" },
	{ 0x6caa0e79, "__gethrtime" },
	{ 0x16927248, "crgetuid" },
	{ 0xffc7c184, "__init_waitqueue_head" },
	{ 0xfe7c4287, "nr_cpu_ids" },
	{ 0xde0bdcff, "memset" },
	{ 0xdd601754, "spl_kmem_cache_destroy" },
	{ 0x81c1c2b2, "vmem_size" },
	{ 0x746ea259, "vn_getf" },
	{ 0xf85ccdae, "kmem_cache_alloc_notrace" },
	{ 0xa5e3d9b9, "__cv_signal" },
	{ 0x99bfbe39, "get_unused_fd" },
	{ 0x5ace355c, "__mutex_init" },
	{ 0xea147363, "printk" },
	{ 0x6e0fbf61, "crgetrgid" },
	{ 0x9b1b5259, "__taskq_wait" },
	{ 0x7ec9bfbc, "strncpy" },
	{ 0x85f8a266, "copy_to_user" },
	{ 0xb4390f9a, "mcount" },
	{ 0xd10b332c, "__cv_timedwait" },
	{ 0x85abc85f, "strncmp" },
	{ 0x3214e5b6, "vmem_free_debug" },
	{ 0x58f53c34, "mutex_lock" },
	{ 0x948cde9, "num_physpages" },
	{ 0x7361eb33, "system_taskq" },
	{ 0xd1fe48c6, "spl_debug_bug" },
	{ 0x521445b, "list_del" },
	{ 0x4b07e779, "_spin_unlock_irqrestore" },
	{ 0xa3d0a92c, "device_create" },
	{ 0x387accf3, "crgetsgid" },
	{ 0xd851af78, "up_write" },
	{ 0x45d55543, "down_write" },
	{ 0x8ecd6eb8, "crgetgid" },
	{ 0x3e0ce02a, "__cv_broadcast" },
	{ 0xbe9fd97f, "spl_kmem_availrmem" },
	{ 0x1c970b92, "cdev_add" },
	{ 0xc230cd4f, "init_task" },
	{ 0xa46952d, "__taskq_create" },
	{ 0x47698e99, "vn_remove" },
	{ 0xa3d922a9, "__cv_wait" },
	{ 0x5732edd1, "crfree" },
	{ 0xf0fdf6cb, "__stack_chk_fail" },
	{ 0xd62c833f, "schedule_timeout" },
	{ 0x1000e51, "schedule" },
	{ 0x286d1c30, "spl_kmem_cache_create" },
	{ 0x654f41a6, "kobj_read_file" },
	{ 0x407a57c3, "__taskq_wait_id" },
	{ 0x3f4547a7, "put_unused_fd" },
	{ 0xa84921e, "spl_kmem_cache_alloc" },
	{ 0x9385667d, "down_read_trylock" },
	{ 0x65f3602b, "vn_releasef" },
	{ 0x3bcdc528, "__cv_init" },
	{ 0x642e54ac, "__wake_up" },
	{ 0x79391bd0, "call_usermodehelper_setup" },
	{ 0x65628a42, "vn_open" },
	{ 0x4958b7b5, "spl_setup" },
	{ 0x3896a905, "__thread_exit" },
	{ 0x37a0cba, "kfree" },
	{ 0x82fe53e1, "ddi_strtol" },
	{ 0x236c8c64, "memcpy" },
	{ 0xebfa36, "fd_install" },
	{ 0x33d92f9a, "prepare_to_wait" },
	{ 0xf68905fd, "ddi_strtoull" },
	{ 0xd9ace09, "ddi_strtoll" },
	{ 0x12fd0fde, "class_destroy" },
	{ 0x9ccb2622, "finish_wait" },
	{ 0x7e9ebb05, "kernel_thread" },
	{ 0x4cbbd171, "__bitmap_weight" },
	{ 0x5dcdfcf0, "kobj_open_file" },
	{ 0x6ac5bec2, "groupmember" },
	{ 0x9edbecae, "snprintf" },
	{ 0xdaa5997c, "spl_kmem_cache_reap_now" },
	{ 0x998a6617, "kmem_alloc_debug" },
	{ 0x4bf8f9, "__thread_create" },
	{ 0x71f938da, "__class_create" },
	{ 0x3302b500, "copy_from_user" },
	{ 0xa2b8a2ba, "__init_rwsem" },
	{ 0xdc43a9c8, "daemonize" },
	{ 0xad052f38, "p0" },
	{ 0xed9b85fc, "__cv_destroy" },
	{ 0xca635a70, "vn_openat" },
	{ 0xa2f3785, "filp_open" },
	{ 0x1f4eafab, "spl_cleanup" },
	{ 0x443c2fa5, "__taskq_destroy" },
};

static const char __module_depends[]
__used
__attribute__((section(".modinfo"))) =
"depends=spl";


MODULE_INFO(srcversion, "A90EFC7E4CECF1EEF69EDB0");

==> spl-0.5.0.tar.gz: spl-0.5.0/module/splat/splat.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
 .arch = MODULE_ARCH_INIT,
};

static const struct modversion_info ____versions[]
__used
__attribute__((section("__versions"))) = {
	{ 0xa5f26ffd, "module_layout" },
	{ 0x3e5770a9, "vn_fsync" },
	{ 0x9a228bdb, "kobject_put" },
	{ 0x84603514, "cdev_del" },
	{ 0x3763d0ce, "per_cpu__current_task" },
	{ 0x5a34a45c, "__kmalloc" },
	{ 0x77e10390, "cdev_init" },
	{ 0xf9a482f9, "msleep" },
	{ 0x51272132, "call_usermodehelper_setfns" },
	{ 0xe23d7acb, "up_read" },
	{ 0x1c1af916, "set_normalized_timespec" },
	{ 0x70242644, "call_usermodehelper_exec" },
	{ 0xd6ee688f, "vmalloc" },
	{ 0x25ec1b28, "strlen" },
	{ 0xa999ab7a, "crhold" },
	{ 0x3b36bf74, "vn_close" },
	{ 0xd8e484f0, "register_chrdev_region" },
	{ 0xfa2e111f, "slab_buffer_size" },
	{ 0x448411f4, "crgetruid" },
	{ 0xc8b57c27, "autoremove_wake_function" },
	{ 0xa8eb7ed0, "vn_getattr" },
	{ 0x950ffff2, "cpu_online_mask" },
	{ 0x79aa04a2, "get_random_bytes" },
	{ 0x67053080, "current_kernel_time" },
	{ 0xb5afb493, "kmem_free_debug" },
	{ 0xd691cba2, "malloc_sizes" },
	{ 0x95bb4182, "rootdir" },
	{ 0xb4279ab7, "downgrade_write" },
	{ 0x2b563692, "kobj_close_file" },
	{ 0x973873ab, "_spin_lock" },
	{ 0xc0a3d105, "find_next_bit" },
	{ 0x15d2fbeb, "kobj_get_filesize" },
	{ 0x6248c005, "crgetngroups" },
	{ 0x105e2727, "__tracepoint_kmalloc" },
	{ 0x1948ac80, "device_destroy" },
	{ 0xbbf89725, "kobject_set_name" },
	{ 0xf7756b61, "vn_rename" },
	{ 0xe04d8f3, "filp_close" },
	{ 0x56b27c, "crgetgroups" },
	{ 0x8bd42035, "__taskq_dispatch" },
	{ 0x1c4bfa6c, "mutex_unlock" },
	{ 0x923cf286, "vn_rdwr" },
	{ 0x7485e15e, "unregister_chrdev_region" },
	{ 0x999e8297, "vfree" },
	{ 0x712aa29b, "_spin_lock_irqsave" },
	{ 0x12f16266, "crgetsuid" },
	{ 0x3c2c5af5, "sprintf" },
	{ 0xe330ba71, "vmem_alloc_debug" },
	{ 0x1190455e, "spl_kmem_cache_free" },
	{ 0x53c639a, "ddi_strtoul" },
	{ 0x7d11c268, "jiffies" },
	{ 0x343a1a8, "__list_add" },
	{ 0xc20925be, "mutex_trylock" },
	{ 0xb4b0ee4e, "down_read" },
	{ 0x24e4bb01, "down_write_trylock" },
	{ 0x6caa0e79, "__gethrtime" },
	{ 0x16927248, "crgetuid" },
	{ 0xffc7c184, "__init_waitqueue_head" },
	{ 0xfe7c4287, "nr_cpu_ids" },
	{ 0xde0bdcff, "memset" },
	{ 0xdd601754, "spl_kmem_cache_destroy" },
	{ 0x2af88b74, "spl_debug_msg" },
	{ 0x81c1c2b2, "vmem_size" },
	{ 0xe4f448b4, "vn_getf" },
	{ 0xf85ccdae, "kmem_cache_alloc_notrace" },
	{ 0x926c1c48, "__cv_signal" },
	{ 0x99bfbe39, "get_unused_fd" },
	{ 0x1e06e977, "__mutex_init" },
	{ 0xea147363, "printk" },
	{ 0x6e0fbf61, "crgetrgid" },
	{ 0xf7995c5f, "__taskq_wait" },
	{ 0x7ec9bfbc, "strncpy" },
	{ 0x85f8a266, "copy_to_user" },
	{ 0xb4390f9a, "mcount" },
	{ 0xac750276, "__cv_timedwait" },
	{ 0x85abc85f, "strncmp" },
	{ 0x3214e5b6, "vmem_free_debug" },
	{ 0x25a26a62, "mutex_lock" },
	{ 0x6dcaeb88, "per_cpu__kernel_stack" },
	{ 0x948cde9, "num_physpages" },
	{ 0x3be2f55d, "system_taskq" },
	{ 0xd1fe48c6, "spl_debug_bug" },
	{ 0x521445b, "list_del" },
	{ 0x4b07e779, "_spin_unlock_irqrestore" },
	{ 0x5bb679c9, "device_create" },
	{ 0x387accf3, "crgetsgid" },
	{ 0xd851af78, "up_write" },
	{ 0x45d55543, "down_write" },
	{ 0x8ecd6eb8, "crgetgid" },
	{ 0xd7d9cc16, "__cv_broadcast" },
	{ 0xbe9fd97f, "spl_kmem_availrmem" },
	{ 0x4a0cab3e, "cdev_add" },
	{ 0x466b0491, "init_task" },
	{ 0xa00a1767, "__taskq_create" },
	{ 0x47698e99, "vn_remove" },
	{ 0x2c7888, "__cv_wait" },
	{ 0x5732edd1, "crfree" },
	{ 0xf0fdf6cb, "__stack_chk_fail" },
	{ 0xd62c833f, "schedule_timeout" },
	{ 0x1000e51, "schedule" },
	{ 0x286d1c30, "spl_kmem_cache_create" },
	{ 0xc731f21a, "kobj_read_file" },
	{ 0x4bb00775, "__taskq_wait_id" },
	{ 0x3f4547a7, "put_unused_fd" },
	{ 0xa84921e, "spl_kmem_cache_alloc" },
	{ 0x9385667d, "down_read_trylock" },
	{ 0x65f3602b, "vn_releasef" },
	{ 0x6363b1ae, "__cv_init" },
	{ 0x642e54ac, "__wake_up" },
	{ 0x30170a32, "call_usermodehelper_setup" },
	{ 0x13e9d2ca, "vn_open" },
	{ 0x4958b7b5, "spl_setup" },
	{ 0x3896a905, "__thread_exit" },
	{ 0x37a0cba, "kfree" },
	{ 0x82fe53e1, "ddi_strtol" },
	{ 0x6067a146, "memcpy" },
	{ 0x8d4d1575, "fd_install" },
	{ 0x33d92f9a, "prepare_to_wait" },
	{ 0xf68905fd, "ddi_strtoull" },
	{ 0xd9ace09, "ddi_strtoll" },
	{ 0xe7594985, "class_destroy" },
	{ 0x9ccb2622, "finish_wait" },
	{ 0x7e9ebb05, "kernel_thread" },
	{ 0x4cbbd171, "__bitmap_weight" },
	{ 0xbba6be0, "kobj_open_file" },
	{ 0x6ac5bec2, "groupmember" },
	{ 0xb5be9d18, "spl_version" },
	{ 0x9edbecae, "snprintf" },
	{ 0xdaa5997c, "spl_kmem_cache_reap_now" },
	{ 0x998a6617, "kmem_alloc_debug" },
	{ 0xe3b50118, "__thread_create" },
	{ 0x5cbfca00, "__class_create" },
	{ 0x3302b500, "copy_from_user" },
	{ 0xa2b8a2ba, "__init_rwsem" },
	{ 0xdc43a9c8, "daemonize" },
	{ 0x20527f69, "p0" },
	{ 0xa0068484, "__cv_destroy" },
	{ 0x1bb31fc0, "vn_openat" },
	{ 0xf372dce7, "filp_open" },
	{ 0x1f4eafab, "spl_cleanup" },
	{ 0xed47671, "__taskq_destroy" },
};

static const char __module_depends[]
__used
__attribute__((section(".modinfo"))) =
"depends=spl";


MODULE_INFO(srcversion, "7A5CB8F8654F85938C987DF");
